[![Build Status](https://travis-ci.org/aplowman/vec-maths.svg?branch=master)](https://travis-ci.org/aplowman/vec-maths)
[![Build status](https://ci.appveyor.com/api/projects/status/m3qak8yixyv6q154/branch/master?svg=true)](https://ci.appveyor.com/project/aplowman/vec-maths/branch/master)
[![CodeFactor](https://www.codefactor.io/repository/github/aplowman/vec-maths/badge/master)](https://www.codefactor.io/repository/github/aplowman/vec-maths/overview/master)

# vec-maths
A collection of maths functions in Python.

## Installation
`pip install vecmaths`
